@@ -33,7 +33,7 @@ package Apache2::AMFWURFLFilterMemcached;
 
   use vars qw($VERSION);
   my $CommonLib = new Apache2::AMFCommonLib ();
-  $VERSION= "3.32";
+  $VERSION= "3.33";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -41,53 +41,8 @@ package Apache2::AMFWURFLFilterMemcached;
   my %Array_DDRcapability;
 
   my %PatchArray_id;
-  my %MobileArray;
-  my %PCArray;
-  $MobileArray{'android'}='mobile';
-  $MobileArray{'bolt'}='mobile';
-  $MobileArray{'brew'}='mobile';
-  $MobileArray{'docomo'}='mobile';
-  $MobileArray{'foma'}='mobile';
-  $MobileArray{'hiptop'}='mobile';
-  $MobileArray{'htc'}='mobile';
-  $MobileArray{'ipod'}='mobile';
-  $MobileArray{'ipad'}='mobile';
-  $MobileArray{'kddi'}='mobile';
-  $MobileArray{'kindle'}='mobile';
-  $MobileArray{'lge'}='mobile';
-  $MobileArray{'maemo'}='mobile';
-  $MobileArray{'midp'}='mobile';
-  $MobileArray{'mobile'}='mobile';
-  $MobileArray{'netfront'}='mobile';
-  $MobileArray{'nintendo'}='mobile';
-  $MobileArray{'nokia'}='mobile';
-  $MobileArray{'novarra'}='mobile';
-  $MobileArray{'palm'}='mobile';
-  $MobileArray{'phone'}='mobile';
-  $MobileArray{'playstation'}='mobile';
-  $MobileArray{'samsung'}='mobile';
-  $MobileArray{'sanyo'}='mobile';
-  $MobileArray{'softbank'}='mobile';
-  $MobileArray{'sony'}='mobile';
-  $MobileArray{'symbian'}='mobile';
-  $MobileArray{'tablet'}='mobile';
-  $MobileArray{'webos'}='mobile';
-  $MobileArray{'windows ce'}='mobile';
-  $MobileArray{'wireless'}='mobile';
-  $MobileArray{'xv6875.1'}='mobile';
-  $MobileArray{'mini'}='mobile';
-  $MobileArray{'mobi'}='mobile';
-  $MobileArray{'SymbOS'}='mobile';
-
-  $PCArray{'msie'}='msie';
-  $PCArray{'msie 5'}='msie_5';
-  $PCArray{'msie 6'}='msie_6';
-  $PCArray{'msie 7'}='msie_7';
-  $PCArray{'msie 8'}='msie_8';
-  $PCArray{'chrome'}='google_chrome';
-  $PCArray{'chrome/0'}='google_chrome_0';
-  $PCArray{'chrome/1'}='google_chrome_1';
-  $PCArray{'chrome/2'}='google_chrome_2';
+  my %MobileArray=$CommonLib->getMobileArray;
+  my %PCArray=$CommonLib->getPCArray;
   my $mobileversionurl="none";
   my $fullbrowserurl="none";
   my $redirecttranscoder="true";
@@ -105,6 +60,7 @@ package Apache2::AMFWURFLFilterMemcached;
   my $personalwurflurl='unknown';
   my $serverMemCache;
   my $restmode='false';
+  my $deepSearch=0;
   
   $CommonLib->printLog("---------------------------------------------------------------------------"); 
   $CommonLib->printLog("-------                 APACHE MOBILE FILTER V$VERSION                  -------");
@@ -249,6 +205,12 @@ sub loadConfigFile {
 			$restmode=$ENV{RestMode};
 			$CommonLib->printLog("RestMode is: $restmode");
 		}
+		if ($ENV{AMFDeepParse}) {
+			$deepSearch=$ENV{AMFDeepParse};
+			$CommonLib->printLog("RestMode is: $deepSearch");			
+		} else {
+				$CommonLib->printLog("AMFDeepParse  is not setted the default value is 3");			   
+		}
 	    $CommonLib->printLog("Finish loading  parameter");
 		$CommonLib->printLog("---------------------------------------------------------------------------"); 
 	    if ($wurflnetdownload eq "true") {
@@ -457,7 +419,7 @@ sub IdentifyUAMethod {
   my $ua_toMatch;
   my $near_toFind=100;
   my $near_toMatch;
-  my %ArrayUAType=$CommonLib->GetMultipleUa(lc($UserAgent));
+  my %ArrayUAType=$CommonLib->GetMultipleUa(lc($UserAgent),$deepSearch);
   foreach $pair (reverse sort { $a <=> $b }  keys	 %ArrayUAType)
   {
       my $dummy=$ArrayUAType{$pair};
@@ -549,19 +511,18 @@ sub parseWURFLFile {
 					$Array_fb{"$id"}=$fb;
 				 }
 				 if (($ua) && ($id)) {
-				         my %ParseUA=$CommonLib->GetMultipleUa($ua);
+				         my %ParseUA=$CommonLib->GetMultipleUa($ua,$deepSearch);
 				         my $pair;
 				         my $arrUaLen = scalar %ParseUA;
 				         my $contaUA=0;
 				         my $Array_fullua_id=$ua;
 				         foreach $pair (reverse sort { $a <=> $b }  keys %ParseUA) {
-						
-						 			my $dummy=$ParseUA{$pair};
-							    if ($Array_id{$dummy}) {} else {
+						 	my $dummy=$ParseUA{$pair};
+							if ($Array_id{$dummy}) {} else {
 						            $Array_id{$dummy}=$id;
-							    }
+							}
 				                $contaUA=$contaUA-1;
-						 }
+					 }
 				 }
 				 
 		 }
@@ -655,7 +616,7 @@ sub handler {
     my $mobile=0;
     my $version="";
     if ($user_agent eq "") {
-	$user_agent="no usergnet found";
+	$user_agent="no useragent found";
     }
     if ($x_user_agent) {
        $user_agent=lc($x_user_agent);
@@ -666,20 +627,20 @@ sub handler {
     if (($query_string) && $restmode eq 'true') {
     		  my @vars = split(/&/, $query_string); 	  
     		  foreach $var (sort @vars){
-    				   if ($var) {
-    						my ($v,$i) = split(/=/, $var);
-    						$v =~ tr/+/ /;
-    						$v =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
-						if ($i) {
-							$i =~ tr/+/ /;
-							$i =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
-							$i =~ s/<!--(.|\n)*-->//g;
-    						$ArrayQuery{$v}=$i;
-						}
-    					}
+    			if ($var) {
+    				my ($v,$i) = split(/=/, $var);
+    				$v =~ tr/+/ /;
+    				$v =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
+				if ($i) {
+					$i =~ tr/+/ /;
+					$i =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
+					$i =~ s/<!--(.|\n)*-->//g;
+					$ArrayQuery{$v}=$i;
+				}
+    			}
     		  }
     	  if ($ArrayQuery{amf}) {
-    				$user_agent=lc($ArrayQuery{amf});
+    		$user_agent=lc($ArrayQuery{amf});
     	  }
 
     }    
@@ -710,7 +671,7 @@ sub handler {
 							$id=IdentifyPCUAMethod($user_agent);
 						}			            
 					}
-				        if ($id) {}else{$id="";};
+				        if (!$id) 	{$id="";};
 					if ($id eq "") { 
 							$id=IdentifyUAMethod($user_agent);
 					}
@@ -790,7 +751,7 @@ Apache2::AMFWURFLFilterMemcached - The module detects the mobile device and pass
 
 =head1 SEE ALSO
 
-For more details: http://www.idelfuschini.it/apache-mobile-filter-v2x.html
+For more details: http://wiki.apachemobilefilter.org
 
 Demo page of the filter: http://www.apachemobilefilter.org
 
